@@ -2,13 +2,12 @@ require 'rubygems'
 require 'ramaze'
 
 class MainController < Ramaze::Controller
-  template_root __DIR__/'template'
   engine :Markaby
 
   helper :markaby
 
   def index
-    %{ #{A 'Home', :href => :/} | #{A(:internal)} | #{A(:external)} }
+    %{ #{a('Home',:/)} | #{a(:internal)} | #{a(:external)} }
   end
 
   def internal *args
@@ -33,7 +32,7 @@ class MainController < Ramaze::Controller
             br
           end
           div do
-            text "The arguments you have passed to this action are:" 
+            text "The arguments you have passed to this action are:"
             if @args.empty?
               text "none"
             else
@@ -55,4 +54,4 @@ class MainController < Ramaze::Controller
   end
 end
 
-Ramaze.start
+Ramaze.start :file => __FILE__
