@@ -1,10 +1,9 @@
 require 'spec/helper'
 spec_require 'haml'
-require 'examples/css'
+require 'examples/misc/css'
 
 describe 'CSSController' do
-  behaves_like 'http'
-  ramaze
+  behaves_like :rack_test
 
   def req(path) r = get(path); [r.content_type, r.body] end
 
