@@ -1,9 +1,9 @@
 require 'spec/helper'
-require 'examples/element'
+spec_require 'nagoro'
+require 'examples/basic/element'
 
 describe 'Element' do
-  behaves_like 'http'
-  ramaze
+  behaves_like :rack_test
 
   it '/' do
     r = get('/').body
