@@ -1,11 +1,10 @@
 require 'spec/helper'
-require 'examples/hello'
+require 'examples/basic/hello'
 
 describe 'Hello' do
-  behaves_like 'http'
-  ramaze
+  behaves_like :rack_test
 
-  it '/' do
+  it 'serves the index page' do
     get('/').body.should == 'Hello, World!'
   end
 end
