@@ -1,9 +1,8 @@
 require 'spec/helper'
-require 'examples/linking'
+require 'examples/basic/linking'
 
 describe 'Linking' do
-  behaves_like 'http'
-  ramaze
+  behaves_like :rack_test
 
   it 'should provide a link to help' do
     r = get('/').body
