@@ -1,9 +1,8 @@
 require 'spec/helper'
-require 'examples/simple'
+require 'examples/basic/simple'
 
 describe 'Simple' do
-  behaves_like 'http'
-  ramaze
+  behaves_like :rack_test
 
   def check(url)
     response = get(url)
@@ -15,10 +14,6 @@ describe 'Simple' do
     check('/').should == 'simple'
   end
 
-  it '/simple' do
-    check('/simple').should =~ /^#<Ramaze::Request/
-  end
-
   it '/join/foo/bar' do
     check('/join/foo/bar').should == 'foobar'
   end
